import pandas as pd


def lnc_filter(data):
    data = data.dropna().drop_duplicates()
    lncrans = pd.read_csv("data/LncSEA+NONCODE+GENCODE.lnc.txt")
    lncrans = set(lncrans["LncRNA"])
    print("---------------Shape: ---------------", data.shape)
    data = data[data.LncRNA.apply(lambda x: x in lncrans)]
    print("---------------Shape: ---------------", data.shape)
    return data


def expand_row(data, col, split=","):
    r = data[col].str.split(split, expand=True)
    r = r.stack().reset_index(level=1, drop=True).dropna().rename(col)
    data = data.drop([col], axis=1).join(r)
    return data


def run(data_path, detail_path):
    ## SmProt2.0 ##
    # SmProt2.0
    print("-----------SmProt2.0------------")
    data = pd.read_csv(data_path[0], sep="\t")
    data = data[
        [
            "GeneType",
            "GeneSymbol",
            "RiboID",
            "smPEP_ID",
            "StartOnTrans",
            "StopOnTrans",
            "TISType",
        ]
    ]
    data.columns = [
        "Set",
        "LncRNA",
        "D1_RiboID",
        "D2_smPEP_ID",
        "D3_StartOnTrans",
        "D4_StopOnTrans",
        "D5_TISType",
    ]
    types = [
        "lncRNA",
        "3prime_overlapping_ncrna",
        "antisense",
        "SenseNoExonic",
        "lincRNA",
        "non-coding",
        "processed_transcript",
        "sense_intronic",
        "Sense_No_Exonic",
        "sense_overlapping",
    ]
    data = data[data["Set"].str.contains("|".join(types))]
    data["Sub_Class"] = "SmProt2.0"
    data["Class"] = "SmORF"
    data.to_csv(detail_path[0], index=False)


run(snakemake.input, snakemake.output)
